LazyDataSet
===========

.. currentmodule:: pykeen.datasets.base

.. autoclass:: LazyDataSet
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~LazyDataSet.testing
      ~LazyDataSet.training
      ~LazyDataSet.validation

   .. rubric:: Attributes Documentation

   .. autoattribute:: testing
   .. autoattribute:: training
   .. autoattribute:: validation
